from com import ensure_init, _tmap_
from OFS.Folder import Folder
from OFS.SimpleItem import SimpleItem
from Globals import InitializeClass, DTMLFile
from AccessControl import ClassSecurityInfo
from AccessControl.Permissions import view_management_screens
from AccessControl.User import SimpleUser
from AccessControl.Role import RoleManager

import Globals
import threading
import User, Role
import Zope
import win32com.client

manage_addADSGroupsFolderForm = DTMLFile('dtml/manage_addADSGroupsFolderForm', globals())

def manage_addADSGroupsFolder(self, id,
                              ldap_domain=None, base_dn=None, search_filter=None, 
                              search_scope=None, 
                              REQUEST=None):
    """Add ADS Group Folder"""
    root = self.getPhysicalRoot()
    has_adsgf = self.ZopeFind(root, obj_metatypes=['ADS Groups Folder'], search_sub=0)
    
    if has_adsgf:
		return Globals.MessageDialog(self,REQUEST,
			title  ='Item Exists',
			message='An ADS Groups Folder already exists somewhere in this Zope',
			action ='%s/manage_main' % REQUEST['URL1'])
			
    folder = ADSGroupsFolder(self, ldap_domain, base_dn, search_filter, search_scope)
    folder.id = str(id)
    folder.title = ldap_domain
    self._setObject(id, folder)
    if REQUEST is not None:
        return self.manage_main(self, REQUEST, update_menu=1)


class ADSGroupsFolder(Folder):

    security = ClassSecurityInfo()
    
    meta_type = 'ADS Groups Folder'
    
    manage_options=(
        (
        {'label' : 'Configure', 'action' : 'manage_main'},
        {'label' : 'Cache', 'action' : 'manage_cache'},
        )
        )

    security.declareProtected(view_management_screens, 'manage_main')
    manage_main = DTMLFile('dtml/manage_editADSGroupsFolderForm',globals())
    
    security.declareProtected(view_management_screens, 'manage_cache')
    manage_cache = DTMLFile('dtml/manage_roleCacheForm', globals())
    
    
    def __init__(self, id, ldap_domain='', base_dn='', 
                 search_filter='', search_scope='subtree'):
        
        self.id = id
        self.ldap_domain = ldap_domain
        self.base_dn = base_dn
        if (search_filter is not None) and (search_filter != ''):
            self.search_filter = search_filter
        else:
            self.search_filter = '*'
        self.search_scope = search_scope
        
        self._lock = threading.Lock()
        
        ensure_init()
        
        # Get ADSI LDAP-Root object for Authentication
        adsns = win32com.client.Dispatch('ADsNameSpaces')
        self._ldapns = adsns.GetObject('','LDAP:')

        # Get ADODB Connection for Authorization
        adocon = win32com.client.Dispatch('ADODB.Connection')
        adocon.Provider = 'ADsDSOObject'
        adocon.Open('Active Directory Provider')
        self._adocon = adocon
        
        

    def manage_editADSGroupsFolder(self, REQUEST):
    	""" Edit ADS Groups Folder Properties """
    		
    	self.ldap_domain   = REQUEST['ldap_domain']
    	self.base_dn       = REQUEST['base_dn']
    	self.search_filter = REQUEST['search_filter']
    	self.search_scope  = REQUEST['search_scope']
   	
        if REQUEST is not None:
            return Globals.MessageDialog(
                title = 'Edited',
                message = "Properties for %s changed." % self.id,
                action = '%s/manage_main' % REQUEST['URL1'])
        return ''
    	
                	
InitializeClass(ADSGroupsFolder)